@@ -440,9 +440,7 @@ modularity <- function(x, ...) {
 #'
 modularity.igraph <- function(x, membership, weights = NULL, resolution = 1, directed = TRUE, ...) {
   # Argument checks
-  if (!is_igraph(x)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(x)
   if (is.null(membership) || (!is.numeric(membership) && !is.factor(membership))) {
     stop("Membership is not a numerical vector")
   }
@@ -475,9 +473,8 @@ modularity.communities <- function(x, ...) {
 #' @export
 modularity_matrix <- function(graph, membership, weights = NULL, resolution = 1, directed = TRUE) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   if (!missing(membership)) {
     warning("The membership argument is deprecated; modularity_matrix does not need it")
   }
@@ -970,9 +967,7 @@ cluster_spinglass <- function(graph, weights = NULL, vertex = NULL, spins = 25,
                               update.rule = c("config", "random", "simple"),
                               gamma = 1.0, implementation = c("orig", "neg"),
                               gamma.minus = 1.0) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
@@ -1014,7 +1009,7 @@ cluster_spinglass <- function(graph, weights = NULL, vertex = NULL, spins = 25,
   } else {
     res <- .Call(
       R_igraph_spinglass_my_community, graph, weights,
-      as.igraph.vs(graph, vertex) - 1, as.numeric(spins),
+      as_igraph_vs(graph, vertex) - 1, as.numeric(spins),
       as.numeric(update.rule), as.numeric(gamma)
     )
     res$community <- res$community + 1
@@ -1128,9 +1123,7 @@ cluster_spinglass <- function(graph, weights = NULL, vertex = NULL, spins = 25,
 cluster_leiden <- function(graph, objective_function = c("CPM", "modularity"),
                            weights = NULL, resolution_parameter = 1, beta = 0.01,
                            initial_membership = NULL, n_iterations = 2, vertex_weights = NULL) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   # Parse objective function argument
   objective_function <- igraph.match.arg(objective_function)
@@ -1243,13 +1236,12 @@ cluster_leiden <- function(graph, objective_function = c("CPM", "modularity"),
 #' @export
 #' @keywords graphs
 #' @examples
-#' g <- graph.famous("Zachary")
+#' g <- make_graph("Zachary")
 #' comms <- cluster_fluid_communities(g, 2)
 cluster_fluid_communities <- function(graph, no.of.communities) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   no.of.communities <- as.integer(no.of.communities)
 
   on.exit(.Call(R_igraph_finalizer))
@@ -1322,9 +1314,7 @@ cluster_fluid_communities <- function(graph, no.of.communities) {
 cluster_walktrap <- function(graph, weights = NULL, steps = 4,
                              merges = TRUE, modularity = TRUE,
                              membership = TRUE) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object!")
-  }
+  ensure_igraph(graph)
 
   if (membership && !modularity) {
     modularity <- TRUE
@@ -1451,9 +1441,7 @@ cluster_edge_betweenness <- function(graph, weights = NULL,
                                      merges = TRUE, bridges = TRUE,
                                      modularity = TRUE,
                                      membership = TRUE) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object!")
-  }
+  ensure_igraph(graph)
 
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
@@ -1536,9 +1524,7 @@ cluster_edge_betweenness <- function(graph, weights = NULL,
 #'
 cluster_fast_greedy <- function(graph, merges = TRUE, modularity = TRUE,
                                 membership = TRUE, weights = NULL) {
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
 
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
@@ -1673,9 +1659,8 @@ cluster_leading_eigen <- function(graph, steps = -1, weights = NULL,
                                   callback = NULL, extra = NULL,
                                   env = parent.frame()) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   steps <- as.integer(steps)
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
@@ -1770,9 +1755,8 @@ cluster_leading_eigen <- function(graph, steps = -1, weights = NULL,
 #'
 cluster_label_prop <- function(graph, weights = NULL, initial = NULL, fixed = NULL) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
   }
@@ -1864,9 +1848,8 @@ cluster_label_prop <- function(graph, weights = NULL, initial = NULL, fixed = NU
 #'
 cluster_louvain <- function(graph, weights = NULL, resolution = 1) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
   }
@@ -1957,9 +1940,8 @@ cluster_louvain <- function(graph, weights = NULL, resolution = 1) {
 #' @keywords graphs
 cluster_optimal <- function(graph, weights = NULL) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   if (is.null(weights) && "weight" %in% edge_attr_names(graph)) {
     weights <- E(graph)$weight
   }
@@ -2036,9 +2018,8 @@ cluster_optimal <- function(graph, weights = NULL) {
 cluster_infomap <- function(graph, e.weights = NULL, v.weights = NULL,
                             nb.trials = 10, modularity = TRUE) {
   # Argument checks
-  if (!is_igraph(graph)) {
-    stop("Not a graph object")
-  }
+  ensure_igraph(graph)
+
   if (is.null(e.weights) && "weight" %in% edge_attr_names(graph)) {
     e.weights <- E(graph)$weight
   }
